from oops import *
from alltests import *



class BindTests(TestCase):
	def runTest(self):
		root = Node()
		root.subnode = Node()
		self.failIf(root.subnode.__path__!=("subnode",), "subnode did not bind correctly (bad path)")
		root.subnode2 = root.subnode
		self.failIf(root.subnode2 is root.subnode, "bound node was rebound instead of copied")


class InheritanceTests(TestCase):
	class NewNode(Node):
		init = 0
		bind = 0
		value = 0
		move = 0
		def __init__(self, value=None, **keywords):
			Node.__init__(self, **keywords)
			if value is not None:
				self.value = value

		def __nonzero__(self):
			return self.value and 1 or 0

		def __bindto__(self, database, path=(), parent=None):
			self.bind = 1
			Node.__bindto__(self, database, path, parent)

		def __moveto__(self, database, path=(), parent=None):
			self.move = 1
			Node.__moveto__(self, database, path, parent)

		def __setval__(self, anything):
			self.value = anything

		def __copyfrom__(self, other):
			Node.__copyfrom__(self, other)
			self.value = other.value

	def runTest(self):
		root = Node()
		root.newnode = self.NewNode()
		self.failUnless(root.newnode.bind, "Node subclass did not bind correctly")

		root.newnode = "New Value!"
		self.failUnless(root.newnode.value == "New Value!", "setval did not work")

		root.newnode2 = root.newnode
		self.failUnless(root.newnode2.value=="New Value!", "copyfrom did not work")

		root.moved_node = self.NewNode("My Value")
		self.failUnless(root.moved_node.move, "move was unsuccessful")


class MoveTests(TestCase):
	def runTest(self):
		root = Node()
		root.newnode = InheritanceTests.NewNode("value")
		self.failUnless(root.newnode.move, "root.newnode was not moved correctly")

		root.newnode_copy = root.newnode
		self.failUnless(root.newnode_copy.value=="value", "root.newnode_copy was not properly copied")




NodeSuite = TestSuite([BindTests(), InheritanceTests(), MoveTests()])
testsuites.append(NodeSuite)
