from alltests import *
from oops import *
import os


class TestObj(Obj):
	unit = Unit()

class UnitTests(TestCase):
	def runTest(self):
		obj = TestObj()
		self.failUnless(obj.unit is None, "default value for unit was not None")
		obj.unit = "Value"
		self.failUnless(obj.unit == "Value", "unit value was different as assigned")
		self.failIf(vars(obj).has_key("unit"), "unit was stored in the instance __dict__")
		self.failUnless("unit" in obj.__unitkeys__, "unit key is not in the keyspace")
		del obj.unit
		self.failIf("unit" in obj.__unitkeys__, "unit key is still in the keyspace after delete")
		self.failUnless(obj.unit is None, "unit value was not None after delete")


class PersistenceTests(TestCase):
	def runTest(self):
		obj = TestObj(filename="myfile.obj")
		obj.unit = "Value"
		del obj
		obj = TestObj(filename="myfile.obj")
		self.failUnless(obj.unit == "Value", "value was not persistently stored")
		del obj
		os.remove("myfile.obj")


class DeepCopyTests(TestCase):
	def runTest(self):
		obj = Node()
		obj.testobj = TestObj()
		obj.testobj.unit = "Value"
		obj.testobj2 = obj.testobj
		self.failUnless(obj.testobj2.unit==obj.testobj.unit, "deep copy failed")

ObjSuite = TestSuite([UnitTests(), PersistenceTests(), DeepCopyTests()])
testsuites.append(ObjSuite)
